@@ -23,13 +23,11 @@ public:
   std::string serverport;
   std::string IPAdress;
   struct addrinfo *p = NULL;
-  uint32_t container_interval;
   uint32_t buffer_size;
 
   static const uint16_t UDP_max_bytesize = 512;
 
-  DVSToUDP(uint32_t interval, uint32_t bfsize, std::string port,
-           std::string IP);
+  DVSToUDP(uint32_t bfsize, std::string port, std::string IP);
 
   void stream(Generator<T> &input_generator, bool include_timestamp);
   void closesocket();
