@@ -14,15 +14,15 @@ class UDPInput {
 private:
   TensorBuffer buffer;
   const int port;
-  const int max_events_per_packet = 1024;
+  static const int max_events_per_packet = 256;
 
   std::thread socket_thread;
   std::atomic<bool> is_serving = {true};
 
 public:
   uint64_t count = 0;
-  UDPInput(torch::IntArrayRef shape, std::string device, int port)
-      : buffer(shape, device), port(port) {}
+  UDPInput(torch::IntArrayRef shape, torch::Device device, int port)
+      : buffer(shape, device, max_events_per_packet), port(port) {}
 
   UDPInput *start_server() {
     std::thread socket_thread(&UDPInput::serve_synchronous, this);
