@@ -7,12 +7,12 @@
 
 #include "tensor_buffer.hpp"
 
-class DVSInput {
+class USBInput {
 
 private:
   Generator<AEDAT::PolarityEvent> generator;
   std::thread socket_thread;
-  static const uint32_t EVENT_BUFFER_SIZE = 100;
+  static const uint32_t EVENT_BUFFER_SIZE = 128;
   TensorBuffer buffer;
   std::atomic<bool> is_streaming = {true};
 
@@ -33,19 +33,32 @@ private:
   };
 
 public:
-  DVSInput(uint16_t deviceId, uint8_t deviceAddress, torch::IntArrayRef shape,
-           std::string device)
-      : buffer(shape, device) {
-    generator = inivation_event_generator("davis", deviceId, deviceAddress);
+  USBInput(torch::IntArrayRef shape, torch::Device device, uint16_t deviceId,
+           uint16_t deviceAddress)
+      : buffer(shape, device, EVENT_BUFFER_SIZE) {
+    if (deviceId > 0) {
+      try {
+        auto address = InivationDeviceAddress{"dvx", deviceId, deviceAddress};
+        generator = inivation_event_generator(address, is_streaming);
+      } catch (std::exception &e) {
+        auto address = InivationDeviceAddress{"davis", deviceId, deviceAddress};
+        generator = inivation_event_generator(address, is_streaming);
+      }
+    } else {
+      generator = inivation_event_generator({}, is_streaming);
+    }
   }
 
   at::Tensor read() { return buffer.read(); }
 
-  DVSInput *start_stream() {
-    std::thread socket_thread(&DVSInput::stream_synchronous, this);
+  USBInput *start_stream() {
+    std::thread socket_thread(&USBInput::stream_synchronous, this);
     socket_thread.detach();
     return this;
   }
 
-  void stop_stream() { is_streaming.store(false); }
-};
+  void stop_stream() {
+    is_streaming.store(false);
+    socket_thread.join();
+  }
+};
\ No newline at end of file
